MiscOptions class

MiscOptions model.

Constructors

MiscOptions({String connectionTestUrl = 'http://cp.cloudflare.com', Duration urlTestInterval = const Duration(minutes: 10), int? clashApiPort = 16756, bool useXrayCoreWhenPossible = false})
const
MiscOptions.fromMap(dynamic raw)
Creates an instance from a dynamic map.
factory

Properties

clashApiPort int?
Documented field.
final
connectionTestUrl String
Documented field.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlTestInterval Duration
Documented field.
final
useXrayCoreWhenPossible bool
Documented field.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Serializes this object to a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited