ParsedVpnSubscription class

Constructors

ParsedVpnSubscription({required String source, required List<VpnProfile> profiles, required List<ParsedVpnConfig> entries, required List<SubscriptionParseFailure> failures, required bool decodedFromBase64})
const

Properties

decodedFromBase64 bool
final
entries List<ParsedVpnConfig>
final
failures List<SubscriptionParseFailure>
final
hashCode int
The hash code for this object.
no setterinherited
profiles List<VpnProfile>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited