SingboxConfigDocument class

Constructors

SingboxConfigDocument.fromJson(String configJson)
factory
SingboxConfigDocument.fromMap(Map<String, Object?> config)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyAdvancedOverride(Map<String, Object?> override) → void
endpointSummaries() List<SingboxEndpointSummary>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLogLevel(String level) → void
toJson({bool pretty = false}) String
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited
updateEndpoint({required int outboundIndex, String? server, int? serverPort, String? remark, String? tag, Map<String, Object?>? advancedPatch}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited