SubscriptionImportResult class

Constructors

SubscriptionImportResult({required ParsedVpnSubscription subscription, required int poolSize, required VpnProfile? appliedProfile, required Map<String, Object?>? appliedConfig})
const

Properties

appliedConfig Map<String, Object?>?
final
appliedProfile VpnProfile?
final
hashCode int
The hash code for this object.
no setterinherited
importedCount int
no setter
invalidCount int
no setter
poolSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscription ParsedVpnSubscription
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited