VpnConnectionSnapshot class

Constructors

VpnConnectionSnapshot({required VpnConnectionState state, required DateTime timestamp, String? lastError, String? detailCode, String? detailMessage, bool? networkValidated, bool? hasInternetCapability, bool? privateDnsActive, String? privateDnsServerName, String? activeInterface, List<String> underlyingTransports = const <String>[]})
const
VpnConnectionSnapshot.fromMap(Map<Object?, Object?> raw)
factory

Properties

activeInterface String?
final
detailCode String?
final
detailMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
hasInternetCapability bool?
final
hasValidationIssue bool
no setter
isConnected bool
no setter
lastError String?
final
networkValidated bool?
final
privateDnsActive bool?
final
privateDnsServerName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state VpnConnectionState
final
timestamp DateTime
final
underlyingTransports List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited