VpnConnectivityProbe class
Constructors
- VpnConnectivityProbe({required String url, required DateTime checkedAt, int? statusCode, Duration? latency, String? error})
-
const
- VpnConnectivityProbe.failure({required String url, required String error})
-
factory
Properties
- checkedAt → DateTime
-
final
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latency → Duration?
-
final
- latencyMs → int?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
final
- success → bool
-
no setter
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited