VpnCoreCapabilities class

Constructors

VpnCoreCapabilities({required String? rawVersion, required String displayVersion, int? semverMajor, int? semverMinor, int? semverPatch, required List<VpnProtocol> supportedProtocols, List<VpnTransport>? supportedTransports})
const

Properties

displayVersion String
final
hashCode int
The hash code for this object.
no setterinherited
hasParsedSemver bool
no setter
rawVersion String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semverMajor int?
final
semverMinor int?
final
semverPatch int?
final
supportedProtocols List<VpnProtocol>
final
supportedTransports List<VpnTransport>
Transports natively supported by the current sing-box core build. Use supportsTransport to check a single transport.
final
unsupportedProtocols List<VpnProtocol>
no setter
unsupportedTransports List<VpnTransport>
Transports from VpnTransport.values NOT natively supported by this build.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsAllTransports(Iterable<VpnTransport> transports) bool
Returns true if every transport in transports is supported.
supportsProtocol(VpnProtocol protocol) bool
supportsTransport(VpnTransport transport) bool
Returns true if the sing-box core natively supports transport.
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited