VpnProfileSummary class

Constructors

VpnProfileSummary({required int index, required String remark, required VpnProtocol protocol, required String host, required int port, required VpnTransport transport, required bool tlsEnabled, String? tlsServerName, List<String> warnings = const <String>[]})
const

Properties

endpoint String
no setter
hashCode int
The hash code for this object.
no setterinherited
host String
final
index int
final
port int
final
protocol VpnProtocol
final
remark String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tlsEnabled bool
final
tlsServerName String?
final
transport VpnTransport
final
warnings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited