TlsTricksOptions class
TlsTricksOptions model.
Constructors
-
TlsTricksOptions({bool enableTlsFragment = false, IntRange tlsFragmentSize = const IntRange(10, 30), IntRange tlsFragmentSleep = const IntRange(2, 8), bool enableTlsMixedSniCase = false, bool enableTlsPadding = false, IntRange tlsPadding = const IntRange(1, 1500), Map<
String, Object?> rawOutboundPatch = const <String, Object?>{}}) -
const
- TlsTricksOptions.fromMap(dynamic raw)
-
Creates an instance from a dynamic map.
factory
Properties
- enableTlsFragment → bool
-
Documented field.
final
- enableTlsMixedSniCase → bool
-
Documented field.
final
- enableTlsPadding → bool
-
Documented field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rawOutboundPatch
→ Map<
String, Object?> -
Documented field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tlsFragmentSize → IntRange
-
Documented field.
final
- tlsFragmentSleep → IntRange
-
Documented field.
final
- tlsPadding → IntRange
-
Documented field.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Serializes this object to a map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited